require 'nokogiri'

module IntelliJ
  module Helpers
    def detect_vcs(path)
      vcs_type = nil
      vcs_type = :Git if ::File.exist?("#{path}/.git")
      vcs_type
    end

    def create_missing_component(name, file, fragment = nil, parent = 'project')
      xml_edit file do
        parent "/#{parent}"
        target "/#{parent}/component[@name=\"#{name}\"]"
        fragment "<component name=\"#{name}\">#{fragment}</component>"
        action :append_if_missing
        only_if { ::File.exist?(file) }
        not_if { ::File.read(file).match(/<component.*name="#{name}".*>/) }
      end
    end

    def create_missing_file(file, source, user  = nil, group  = nil, variables = nil)
      directory ::File.dirname(file) do
        recursive true
        user user
        group group
      end

      template file do
        source source
        cookbook 'intellij'
        user user
        group group
        variables variables
        action :create_if_missing
      end
    end

    def process_xpath_in_xml(file, xpath)
      result = nil
      if ::File.exist?(file)
        doc = Nokogiri::XML(File.read(file), &:noblanks)
        namespace = doc.root.namespaces
        result = doc.xpath(xpath, namespace)
      end
      result
    end

    def xpath_exists?(file, xpath)
      !process_xpath_in_xml(file, xpath).to_s.empty?
    end

    def pretty_format_xml(xml, indent = 2)
      Nokogiri::XML(xml, &:noblanks).root.to_xml(indent: indent)
    end

    def get_tmp_path(filename)
      "#{Dir.tmpdir}/#{::File.basename(filename)}"
    end

    def edition_short_code(edition)
      editions = {ultimate: 'IU', community: 'IC'}
      editions[edition.to_sym]
    end

    def edition_code(edition)
      editions = {ultimate: 'IIU', community: 'IIC'}
      editions[edition.to_sym]
    end

    def product_edition_code(edition)
      editions = {ultimate: 'idea', community: 'idea_ce'}
      editions[edition.to_sym]
    end

    def local_intellij_info(path)
      result = nil
      file = "#{path}/product-info.json"
      if ::File.exist?(file)
        info = JSON.parse(::File.read(file))
        result = [info['version'], info['productCode']]
      end
      result
    end

    def project_relative_path(path, project_path)
      path.gsub(project_path, '$PROJECT_DIR$')
    end

    def map_to_xml_attributes(map)
      result = []
      map.each do |key, value|
        result.push("#{key}=\"#{value}\"") unless value.to_s.empty?
      end
      result.join(' ')
    end
  end
end
