resource_name :intellij_run_configuration
default_action :create

property :project_path, String, required: true
property :config_name, String, name_property: true
property :type, String, required: true
property :factory, String
property :folder, String
property :body, String, required: true
property :user, String
property :group, String
property :attributes, Hash

include IntelliJ::Workspace::RunConfiguration
include IntelliJ::Helpers

action :create do
  args = @new_resource

  attributes = {
    name: args.config_name,
    type: args.type,
    factory: args.factory,
    folderName: args.folder,
  }.merge(args.attributes || {})

  xml = generate_run_config_xml(attributes, args.body)

  file = "#{args.project_path}/.idea/workspace.xml"

  create_missing_file(file, 'project/workspace.xml', args.user, args.group)
  create_missing_component('RunManager', file)

  xml_edit file do
    parent '/project/component[@name="RunManager"]'
    target "/project/component[@name=\"RunManager\"]/configuration[@name=\"#{args.config_name}\"]"
    fragment xml
    action :append_if_missing
  end
end

action :delete do
  args = @new_resource
  file = "#{args.project_path}/.idea/workspace.xml"

  xml_edit file do
    target "/project/component[@name=\"RunManager\"]/configuration[@name=\"#{args.config_name}\"]"
    action :remove
    only_if { ::File.exist?(file) }
  end
end
